[−][src]Struct type_checking::type_system::ClassMethodDef
Fields
name: Symbol<'src>
Name of the method
body: ClassMethodBody<'src, 'ast>
params: Vec<Rc<MethodParamDef<'src>>>
params does not include this for non-static / non-main methods
return_ty: CheckedType<'src>
is_static: bool
is_main: bool
Methods
impl<'src, 'ast> ClassMethodDef<'src, 'ast>[src]
impl<'src, 'ast> ClassMethodDef<'src, 'ast>pub fn new(
name: Symbol<'src>,
body: ClassMethodBody<'src, 'ast>,
params: Vec<MethodParamDef<'src>>,
return_ty: CheckedType<'src>,
is_static: bool
) -> ClassMethodDef<'src, 'ast>[src]
pub fn new(
name: Symbol<'src>,
body: ClassMethodBody<'src, 'ast>,
params: Vec<MethodParamDef<'src>>,
return_ty: CheckedType<'src>,
is_static: bool
) -> ClassMethodDef<'src, 'ast>Trait Implementations
impl<'src, 'ast> Debug for ClassMethodDef<'src, 'ast>[src]
impl<'src, 'ast> Debug for ClassMethodDef<'src, 'ast>Auto Trait Implementations
impl<'src, 'ast> !Send for ClassMethodDef<'src, 'ast>
impl<'src, 'ast> !Send for ClassMethodDef<'src, 'ast>impl<'src, 'ast> !Sync for ClassMethodDef<'src, 'ast>
impl<'src, 'ast> !Sync for ClassMethodDef<'src, 'ast>Blanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut Timpl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeId